@@ -48,6 +48,17 @@
 #define AMD_COMGR_CALL
 #endif
 
+// Add deprecation support for Comgr on Linux
+// This can be removed in favor of generic [[deprecated]] in C23, which should
+// also allow us to more easily include support on Windows
+#ifndef AMD_COMGR_DEPRECATED
+#if defined __GNUC__ && (__GNUC__ > 5 || defined __clang__)
+#define AMD_COMGR_DEPRECATED(msg) __attribute__((deprecated(msg)))
+#else // Windows systems, and GCC older than 6.0
+#define AMD_COMGR_DEPRECATED(msg) // empty
+#endif
+#endif
+
 #ifndef AMD_COMGR_EXPORT_DECORATOR
 #ifdef __GNUC__
 #define AMD_COMGR_EXPORT_DECORATOR __attribute__ ((visibility ("default")))
@@ -76,7 +87,7 @@
 #endif
 
 #define AMD_COMGR_INTERFACE_VERSION_MAJOR 2
-#define AMD_COMGR_INTERFACE_VERSION_MINOR 5
+#define AMD_COMGR_INTERFACE_VERSION_MINOR 6
 
 #ifdef __cplusplus
 extern "C" {
@@ -192,6 +203,12 @@ extern "C" {
  */
 #define AMD_COMGR_VERSION_2_5
 
+/**
+ * The function was introduced or changed in version 2.6 of the interface
+ * and has the symbol version string of ``"amd_comgr_2.6"``.
+ */
+#define AMD_COMGR_VERSION_2_6
+
 /** @} */
 
 /**
@@ -208,7 +225,9 @@ typedef enum amd_comgr_status_s {
   AMD_COMGR_STATUS_ERROR = 0x1,
   /**
    * One of the actual arguments does not meet a precondition stated
-   * in the documentation of the corresponding formal argument.
+   * in the documentation of the corresponding formal argument. This
+   * includes both invalid Action types, and invalid arguments to
+   * valid Action types.
    */
   AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT = 0x2,
   /**
@@ -474,7 +493,9 @@ amd_comgr_get_isa_name(
  * @brief Get a handle to the metadata of an isa name.
  *
  * The structure of the returned metadata is isa name specific and versioned
- * with details specified in README.md. It can include information about the
+ * with details specified in
+ * https://llvm.org/docs/AMDGPUUsage.html#code-object-metadata.
+ * It can include information about the
  * limits for resources such as registers and memory addressing.
  *
  * @param[in] isa_name The isa name to query.
@@ -1208,6 +1229,8 @@ amd_comgr_action_info_get_language(
  * @deprecated since 1.3
  * @see amd_comgr_action_info_set_option_list
  */
+AMD_COMGR_DEPRECATED("Will be removed in Comgr v3.0 (Rocm v6.0). Use "
+                     "amd_comgr_action_info_set_option_list() instead")
 amd_comgr_status_t AMD_COMGR_API
 amd_comgr_action_info_set_options(
   amd_comgr_action_info_t action_info,
@@ -1248,6 +1271,10 @@ amd_comgr_action_info_set_options(
  * @see amd_comgr_action_info_get_option_list_count and
  * amd_comgr_action_info_get_option_list_item
  */
+AMD_COMGR_DEPRECATED("Will be removed in Comgr v3.0 (Rocm v6.0). Use "
+                     "amd_comgr_action_info_get_option_list_count() "
+                     "and amd_comgr_action_info_get_option_list_item() "
+                     "instead")
 amd_comgr_status_t AMD_COMGR_API
 amd_comgr_action_info_get_options(
   amd_comgr_action_info_t action_info,
@@ -1538,7 +1565,10 @@ typedef enum amd_comgr_action_kind_s {
    * The @c AMD_COMGR_ACTION_COMPILE_SOURCE_WITH_DEVICE_LIBS_TO_BC action can
    * be used as a workaround which ensures the link occurs correctly.
    */
-  AMD_COMGR_ACTION_ADD_DEVICE_LIBRARIES = 0x3,
+  AMD_COMGR_ACTION_ADD_DEVICE_LIBRARIES
+  AMD_COMGR_DEPRECATED("Will be removed in Comgr v3.0 (Rocm v6.0). Use "
+                       "AMD_COMGR_ACTION_COMPILE_SOURCE_WITH_DEVICE_LIBS_TO_BC "
+                       "instead") = 0x3,
   /**
    * Link a collection of bitcodes, bundled bitcodes, and bundled bitcode
    * archives in @p into a single composite (unbundled) bitcode @p.
@@ -1681,8 +1711,15 @@ typedef enum amd_comgr_action_kind_s {
    *
    * Return @p AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT
    * if isa name or language is not set in @p info.
+   *
+   * @deprecated since 2.5
+   * @see in-process compilation via AMD_COMGR_ACTION_COMPILE_SOURCE_TO_BC, etc.
+   * insteaad
    */
-  AMD_COMGR_ACTION_COMPILE_SOURCE_TO_FATBIN = 0xE,
+  AMD_COMGR_ACTION_COMPILE_SOURCE_TO_FATBIN
+  AMD_COMGR_DEPRECATED("Will be removed in Comgr v3.0 (Rocm v6.0). Use "
+                       "AMD_COMGR_ACTION_COMPILE_SOURCE_TO_BC, etc. "
+                       "instead") = 0xE,
   /**
    * Compile each source data object in @p input in order. For each
    * successful compilation add a bc data object to @p result. Resolve
@@ -2355,6 +2392,76 @@ amd_comgr_get_mangled_name(
     size_t *size,
     char *mangled_name) AMD_COMGR_VERSION_2_5;
 
+/**
+ * @brief Populate a name expression map from a given code object.
+ *
+ * Used to map stub names *__amdgcn_name_expr_* in bitcodes and code
+ * objects generated by hip runtime to an associated (unmangled) name
+ * expression and (mangled) symbol name.
+ *
+ * @param[in] data A data object of kind @p
+ * AMD_COMGR_DATA_KIND_EXECUTABLE or @p AMD_COMGR_DATA_KIND_BC
+ *
+ * @param[out] count The number of name expressions mapped. This value
+ * can be used as an upper bound to the Index provided to the corresponding
+ * amd_comgr_map_name_expression_to_symbol_name() call.
+ *
+ * @retval ::AMD_COMGR_STATUS_SUCCESS The function executed successfully.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT @p data is
+ * an invalid data object or not of kind @p AMD_COMGR_DATA_KIND_EXECUTABLE or
+ * @p AMD_COMGR_DATA_KIND_BC.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR LLVM API failure, which should be
+ * accompanied by an LLVM error message to stderr
+ *
+ */
+amd_comgr_status_t AMD_COMGR_API
+amd_comgr_populate_name_expression_map(
+    amd_comgr_data_t data,
+    size_t *count) AMD_COMGR_VERSION_2_6;
+
+/**
+ * @brief Fetch a related symbol name for a given name expression;
+ * or that name's length.
+ *
+ * The @p data must have had its name expression map populated with @p
+ * amd_comgr_populate_name_expression_map.
+ *
+ * @param[in] data A data object of kind @p
+ * AMD_COMGR_DATA_KIND_EXECUTABLE or @p AMD_COMGR_DATA_KIND_BC used to
+ * identify which map of name expressions to retrieve from.
+ *
+ * @param[in, out] size For out, the size of @p symbol_name. For in,
+ * if @symbol_name is NULL, set to the size of the Nth option string including
+ * the terminating null character.
+ *
+ * @param[in] name_expression A character array of a name expression. This name
+ * is used as the key to the name expression map in order to locate the desired
+ * @symbol_name.
+ *
+ * @param[out] symbol_name If not NULL, then the first @p size characters of
+ * the symbol name string mapped from @name_expression are copied into @p
+ * symbol_name. If NULL, no symbol name string is copied, and only @p size is
+ * updated (useful in order to find the size of the buffer required to copy the
+ * symbol_name string).
+ *
+ * @retval ::AMD_COMGR_STATUS_SUCCESS The function executed successfully.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR @p data object is not valid (NULL or not of
+ * type bitcode or code object)
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT @p name_expression is not
+ * present in the name expression map.
+ *
+ */
+amd_comgr_status_t AMD_COMGR_API
+amd_comgr_map_name_expression_to_symbol_name(
+    amd_comgr_data_t data,
+    size_t *size,
+    char *name_expression,
+    char *symbol_name) AMD_COMGR_VERSION_2_6;
+
 /**
  * @brief A data structure for Code object information.
  */
